%define idlever 0.5
%define realver 2.0

Summary:	An interpreted, interactive object-oriented programming language
Name:		python
Version:	2.0
Release:	9mdk
License:	Modified CNRI Open Source License
Group:		Development/Python

Source:		Python-%{realver}.tar.bz2
Source1:	html-%{realver}.tar.bz2
Patch0:		python-2.0-config.patch.bz2

URL:		http://www.pythonlabs.com/
Icon:		python-logo.xpm
Buildroot:	%_tmppath/%name-%version-%release-root
Conflicts:	tkinter < %{version}
BuildRequires:	gmp-devel tix tk tcl gdbm-devel gpm-devel ncurses-devel blt
BuildRequires:	readline-devel zlib-devel XFree86-devel openssl-devel emacs
BuildRequires:	expat-devel libxode1-devel libtermcap-devel

%description
Python is an interpreted, interactive, object-oriented programming
language often compared to Tcl, Perl, Scheme or Java. Python includes
modules, classes, exceptions, very high level dynamic data types and
dynamic typing. Python supports interfaces to many system calls and
libraries, as well as to various windowing systems (X11, Motif, Tk,
Mac and MFC).

Programmers can write new built-in modules for Python in C or C++.
Python can be used as an extension language for applications that
need a programmable interface. This package contains most of the
standard Python modules, as well as modules for interfacing to the
Tix widget set for Tk and RPM.

Note that documentation for Python is provided in the python-docs
package.

%package devel
Summary:	The libraries and header files needed for Python development
Icon:		python-devel-logo.xpm
Requires:	python = %version-%release
Group:		Development/Python

%description devel
The Python programming language's interpreter can be extended with
dynamically loaded extensions and can be embedded in other programs.
This package contains the header files and libraries needed to do
these types of tasks.

Install python-devel if you want to develop Python extensions.  The
python package will also need to be installed.  You'll probably also
want to install the python-docs package, which contains Python
documentation.

%package docs
Summary:	Documentation for the Python programming language
Icon:		python-docs-logo.xpm
Requires:	python = %version-%release
Group:		Development/Python

%description docs
The python-docs package contains documentation on the Python
programming language and interpreter.  The documentation is provided
in ASCII text files and in LaTeX source files.

Install the python-docs package if you'd like to use the documentation
for the Python language.

%package -n tkinter
Summary:	A graphical user interface for the Python scripting language
Group:		Development/Python
Icon:		python-tkinter-logo.xpm
Requires:	libtcl8.3.so libtk8.3.so
Requires:	python = %version-%release

%description -n tkinter
The Tkinter (Tk interface) program is an graphical user interface for
the Python scripting language.

You should install the tkinter package if you'd like to use a graphical
user interface for Python programming.

%prep
%setup -q -n Python-%{version}
%patch -p1 -b .mdk 

mkdir html
bzcat %{SOURCE1} | tar xv  -C html

echo ': ${LDSHARED='gcc -shared'}' > config.cache
echo ': ${LINKFORSHARED='-rdynamic'}' >> config.cache
echo ': ${CCSHARED='-fPIC'}' >> config.cache

# fix cgi script
perl -p -i -e 's|/usr/local/bin/python|/usr/bin/env python|g' Lib/cgi.py
# pull in the obsolete rand.py
cp Lib/lib-old/rand.py Lib

%build
OPT="$RPM_OPT_FLAGS -DINT_MAX=2147483647"
export OPT
MACHDEP=linux-$RPM_ARCH ./configure --prefix=/usr --with-threads --with-cycle-gc --with-cxx=g++ --without-libdb

make

%{?rpmcheck:make test}

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{_prefix}

# python is not GNU and does not know fsstd
mkdir -p $RPM_BUILD_ROOT%{_mandir}
%makeinstall MANDIR=$RPM_BUILD_ROOT%{_mandir}

# emacs, I use it, I want it
mkdir -p $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp
install -m 644 Misc/python-mode.el $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp
emacs -batch -f batch-byte-compile $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp/python-mode.el

install -d $RPM_BUILD_ROOT%{_sysconfdir}/emacs/site-start.d
cat <<EOF >$RPM_BUILD_ROOT%{_sysconfdir}/emacs/site-start.d/%{name}.el
(setq auto-mode-alist (cons '("\\\\.py$" . python-mode) auto-mode-alist))
(autoload 'python-mode "python-mode" "Mode for python files." t)
EOF

# idle
mkdir -p $RPM_BUILD_ROOT%{_libdir}/python2.0/site-packages
cat << EOF > $RPM_BUILD_ROOT%{_bindir}/idle
#!/bin/bash
exec /usr/lib/python2.0/site-packages/idle/idle.py
EOF
cp -r Tools/idle $RPM_BUILD_ROOT%{_libdir}/python2.0/site-packages/

# modulator
cat << EOF > $RPM_BUILD_ROOT%{_bindir}/modulator
#!/bin/bash
exec /usr/lib/python2.0/site-packages/modulator/modulator.py
EOF
cp -r Tools/modulator $RPM_BUILD_ROOT%{_libdir}/python2.0/site-packages/

# pynche
cat << EOF > $RPM_BUILD_ROOT%{_bindir}/pynche
#!/bin/bash
exec /usr/lib/python2.0/site-packages/pynche/pynche
EOF
rm -f Tools/pynche/*.pyw
cp -r Tools/pynche $RPM_BUILD_ROOT%{_libdir}/python2.0/site-packages/

chmod 755 $RPM_BUILD_ROOT%{_bindir}/{idle,modulator,pynche}

ln -f Tools/modulator/README Tools/modulator/README.modulator
ln -f Tools/pynche/README Tools/pynche/README.pynche

rm -f modules-list.full
for n in $RPM_BUILD_ROOT/usr/lib/python%{version}/*; do
  [ -d $n ] || echo $n
done >> modules-list.full

for mod in $RPM_BUILD_ROOT/usr/lib/python%{version}/lib-dynload/* ; do
  [ `basename $mod` = _tkinter.so ] || echo $mod
done >> modules-list.full
sed -e "s|$RPM_BUILD_ROOT||g" < modules-list.full > modules-list


# menu support
mkdir -p $RPM_BUILD_ROOT%{_libdir}/menu
cat > $RPM_BUILD_ROOT/%{_menudir}/tkinter << EOF
#?package(%{name}): needs=text section="Applications/Development/Interpreters" title=Python command=python
?package(tkinter): needs="gnome" section="Applications/Development/Development environments" title="IDLE" \
longtitle="IDE for Python" command="NO_XALF %{_bindir}/idle" icon="development_section.xpm"
?package(tkinter): needs=x11 section="Applications/Development/Development environments" title="IDLE" \
longtitle="IDE for Python" command="%{_bindir}/idle" icon="development_section.xpm"
EOF

# remove executable scripts
chmod -x $RPM_BUILD_ROOT/usr/lib/python2.0/test/test_binascii.py $RPM_BUILD_ROOT/usr/lib/python2.0/site-packages/idle/BrowserControl.py

find $RPM_BUILD_ROOT -type f -exec perl -pi -e "s|$RPM_BUILD_ROOT||g" {} \;

%clean
rm -rf $RPM_BUILD_ROOT
rm -f modules-list modules-list.full

%files -f modules-list
%defattr(-, root, root, 755)
%{_bindir}/python
%{_mandir}/man1/python*
%dir %{_libdir}/python*
%dir %{_libdir}/python*/lib-dynload
%{_libdir}/python*/curses/*
%{_libdir}/python*/distutils/*
%{_libdir}/python*/encodings/*
%{_libdir}/python*/lib-old/*
%{_libdir}/python*/xml/*
%dir %{_libdir}/python*/site-packages
%{_libdir}/python*/plat-linux-*/*
%{_datadir}/emacs/site-lisp/python-mode.el
%config(noreplace) %{_sysconfdir}/emacs/site-start.d/%{name}.el

%files devel
%defattr(-, root, root, 755)
%dir %{_includedir}/python*
%{_includedir}/python*/*
%{_libdir}/python*/config/*
%{_libdir}/python*/test/*


%files docs
%defattr(-,root,root,755)
%doc html/*

%files -n tkinter
%defattr(-, root, root, 755)
%dir %{_libdir}/python*/lib-tk
%{_libdir}/python*/lib-tk/*.py*
%{_libdir}/python*/lib-dynload/_tkinter.so
%{_libdir}/python*/site-packages/idle
%{_libdir}/python*/site-packages/modulator
%{_libdir}/python*/site-packages/pynche
%{_libdir}/menu/tkinter
%{_bindir}/idle
%{_bindir}/pynche
%{_bindir}/modulator

%post -n tkinter
%update_menus

%postun -n tkinter
%clean_menus

%changelog
* Wed Apr 11 2001 Frederic Crozat <fcrozat@mandrakesoft.com> 2.0-9mdk
- Correct GNOME menu entry

* Sun Apr  8 2001 Frederic Lepied <flepied@mandrakesoft.com> 2.0-8mdk
- added missing xml directory
- added an optional make test at the end of the %build section

* Fri Mar 30 2001 Frederic Lepied <flepied@mandrakesoft.com> 2.0-6mdk
- correct launching of scripts (#2802)

* Tue Mar 27 2001 Frederic Lepied <flepied@mandrakesoft.com> 2.0-5mdk
- added libtermcap-devel to BuildRequires.

* Sat Mar 24 2001 David BAUDENS <baudens@mandrakesoft.com> 2.0-4mdk
- BuildRequires: libxode1-devel
- Requires: %%version-%%release and not only %%version

* Mon Mar 19 2001 Pixel <pixel@mandrakesoft.com> 2.0-3mdk
- fix the python.el (\\. -> \\\\.)

* Fri Dec  8 2000 Frederic Lepied <flepied@mandrakesoft.com> 2.0-2mdk
- added blt and expat-devel BuildRequires:

* Fri Nov 17 2000 Frederic Lepied <flepied@mandrakesoft.com> 2.0-1mdk
- 2.0 (95 tests OK. 12 tests skipped: test_al test_cd test_cl test_dl test_gl test_imgfile test_largefile
test_linuxaudiodev test_nis test_sunaudiodev test_winreg test_winsound)
- added emacs mode
- html doc.

* Wed Sep 27 2000 Frederic Lepied <flepied@mandrakesoft.com> 1.5.2-12mdk
- removed dependency on tkinter for python to avoid loop.

* Mon Sep 11 2000 Frederic Lepied <flepied@mandrakesoft.com> 1.5.2-11mdk
- fixed some hardcoded paths (Geoffrey Lee).
- removed menu entry for interpreter.

* Thu Aug 10 2000 Guillaume Cottenceau <gc@mandrakesoft.com> 1.5.2-10mdk
- fixed typo %updates_menus -> %update_menus

* Mon Aug 07 2000 Frederic Lepied <flepied@mandrakesoft.com> 1.5.2-9mdk
- automatically added BuildRequires

* Thu Aug  3 2000 Chmouel Boudjnah <chmouel@mandrakesoft.com> 1.5.2-8mdk
- Merge rh patch.
- Macros.
- compile with new tcl.

* Tue May  9 2000 Frederic Lepied <flepied@mandrakesoft.com> 1.5.2-7mdk
- added locale module.

* Thu Mar 30 2000 Frederic Lepied <flepied@mandrakesoft.com> 1.5.2-6mdk
- menu

* Tue Mar  7 2000 Frederic Lepied <flepied@mandrakesoft.com> 1.5.2-5mdk
- idle 0.5.
- compiled with optimization.

* Fri Jan 14 2000 Frederic Lepied <flepied@mandrakesoft.com> 1.5.2-4mdk

- added a BuildRequires.

* Sat Dec 4 1999 Florent Villard <warly@mandrakesoft.com>
- add idle, pynche and modulator in the package

* Tue Oct 19 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>
- Merge with redhat changes.
- added modulator, and pynche to the python-tools package(r)
- using a files list in the %files section for python-tools(r)
- added conflicts/requires between subpackages so that you cannot
  have an older tkinter installed with a new python.(r)
- added more tools(r)
- rebuild to fix broken tkinter.(r)
- fixed bogus /usr/local/bin/python requirements.(r)
- added patch to import global symbols until we get libtool patched(r)

* Fri Aug 20 1999 Pablo Saratxaga <pablo@mandrakesoft.com>
- updated to 1.5.2
- updated patches
- use macro %%{_arch} instead of %%{_target_cpu} for file paths

* Tue Apr 13 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>
- Remove the dbm support (doen't work with GLBC2.1)

* Sat Apr 10 1999 Bernhard Rosenkraenzer <bero@linux-mandrake.com>
- Mandrake adaptions
- add de locale
- fix handling of RPM_OPT_FLAGS

* Thu Feb 11 1999 Michael Johnson <johnsonm@redhat.com>
- added mpzmodule at user request (uses gmp)
- added bsddbmodule at user request (uses db 1.85 interface)

* Mon Feb 08 1999 Michael Johnson <johnsonm@redhat.com>
- add --with-threads at user request
- clean up spec file

* Fri Jan 08 1999 Michael K. Johnson <johnsonm@redhat.com>
- New libc changes ndbm.h to db1/ndbm.h and -ldb to -ldb1

* Thu Sep  3 1998 Jeff Johnson <jbj@redhat.com>
- recompile for RH 5.2.

* Wed May 06 1998 Cristian Gafton <gafton@redhat.com>
- python-docs used to require /usr/bin/sed. Changed to /bin/sed instead

* Wed Apr 29 1998 Cristian Gafton <gafton@redhat.com>
- fixed the spec file for version 1.5.1
- buildroot (!)

* Mon Apr 20 1998 Michael K. Johnson <johnsonm@redhat.com>
- updated to python 1.5.1
- created our own Python-Doc tar file from 1.5 to substitute for the
  not-yet-released Doc package.
- build _tkinter properly
- use readline again
- build crypt module again
- install rand replacement module
- added a few modules

* Thu Apr 09 1998 Erik Troan <ewt@redhat.com>
- updated to python 1.5
- made /usr/lib/python1.5 file list automatically generated

* Tue Nov 04 1997 Michael K. Johnson <johnsonm@redhat.com>
- Fixed dependencies for python and tkinter

* Mon Nov 03 1997 Michael K. Johnson <johnsonm@redhat.com>
- pulled out tk-related stuff into tkinter package

* Fri Oct 10 1997 Erik Troan <ewt@redhat.com>
- bunches of scripts used /usr/local/bin/python instead of /usr/bin/python

* Tue Sep 30 1997 Erik Troan <ewt@redhat.com>
- updated for tcl/tk 8.0

* Thu Jul 10 1997 Erik Troan <ewt@redhat.com>
- built against glibc
